@@ -75,6 +75,14 @@ sub import {
     $planet->call(@_);
   });
 
+  # inc function
+  $planet->space->inject('inc', sub {
+    my ($name) = @_;
+    $planet->space->inject($name =~ s/\W//gr, sub {
+      $planet->call($name, @_);
+    });
+  });
+
   # service functions
   for my $name (keys %{$planet->config}) {
     unless ($planet->space->routine($name)) {
@@ -211,7 +219,7 @@ L<Data::Object::Boolean> object.
 
   float;
 
-This package supports making the C<float> function available in the)calling
+This package supports making the C<float> function available in the calling
 package if it doesn't exist already. This function creates a
 L<Data::Object::Float> object.
 
@@ -223,19 +231,36 @@ L<Data::Object::Float> object.
 
   hash;
 
-This package supports making the C<hash> function available in the)calling
+This package supports making the C<hash> function available in the calling
 package if it doesn't exist already. This function creates a
 L<Data::Object::Hash> object.
 
 =cut
 
+=head2 inc
+
+  # given: synopsis
+
+  inc 'Data::Dumper';
+
+  # creates a DataDumper function
+
+  DataDumper('Dumper', {1..4});
+
+This package supports making the C<inc> function available in the calling
+package. When used, this function creates a function after the name provided
+which calls into the named package. Special characters are stripped from the
+function name.
+
+=cut
+
 =head2 number
 
   # given: synopsis
 
   number;
 
-This package supports making the C<number> function available in the)calling
+This package supports making the C<number> function available in the calling
 package if it doesn't exist already. This function creates a
 L<Data::Object::Number> object.
 
@@ -247,7 +272,7 @@ L<Data::Object::Number> object.
 
   regexp;
 
-This package supports making the C<regexp> function available in the)calling
+This package supports making the C<regexp> function available in the calling
 package if it doesn't exist already. This function creates a
 L<Data::Object::Regexp> object.
 
@@ -259,7 +284,7 @@ L<Data::Object::Regexp> object.
 
   space;
 
-This package supports making the C<space> function available in the)calling
+This package supports making the C<space> function available in the calling
 package if it doesn't exist already. This function creates a
 L<Data::Object::Space> object.
 
@@ -271,7 +296,7 @@ L<Data::Object::Space> object.
 
   string;
 
-This package supports making the C<string> function available in the)calling
+This package supports making the C<string> function available in the calling
 package if it doesn't exist already. This function creates a
 L<Data::Object::String> object.
 
@@ -283,7 +308,7 @@ L<Data::Object::String> object.
 
   true;
 
-This package supports making the C<true> function available in the)calling
+This package supports making the C<true> function available in the calling
 package if it doesn't exist already. This function creates a
 L<Data::Object::Boolean> object.
 
